This directory contains example schema files describing test suites. To add a
test suite to an LNT server, use the `lnt admin test-suite add` command to upload
the schema definition of the test suite to the database. Alternatively, for local
development, you can copy these files or create symlinks to the schemas directory
of an lnt instance to have them loaded automatically on server startup.
